@@ -69,15 +69,16 @@ APPEND_METAVARS_HELP = False  # Append metavar (eg. [TEXT]) after the help text
 GROUP_ARGUMENTS_OPTIONS = False  # Show arguments with options instead of in own panel
 USE_MARKDOWN = False  # Parse help strings as markdown
 USE_RICH_MARKUP = False  # Parse help strings for rich markup (eg. [red]my text[/])
-COMMAND_GROUPS = {}
-OPTION_GROUPS = {}
+COMMAND_GROUPS = {}  # Define sorted groups of panels to display subcommands
+OPTION_GROUPS = {}  # Define sorted groups of panels to display options and arguments
+USE_CLICK_SHORT_HELP = False  # Use click's default function to truncate help text
 
 
 # Rich regex highlighter
 class OptionHighlighter(RegexHighlighter):
     highlights = [
-        r"(^|\W)(?P<switch>\-\w+)(?!\S)",
-        r"(^|\W)(?P<option>\-\-[\w\-]+)(?!\S)",
+        r"(^|\W)(?P<switch>\-\w+)(?![a-zA-Z0-9])",
+        r"(^|\W)(?P<option>\-\-[\w\-]+)(?![a-zA-Z0-9])",
         r"(?P<metavar>\<[^\>]+\>)",
         r"(?P<usage>Usage: )",
     ]
@@ -351,28 +352,16 @@ def rich_format_help(obj, ctx, formatter):
                 continue
 
             # Short and long form
-            if len(param.opts) == 2:
-                # Always have the --long form first
-                if "--" in param.opts[0]:
-                    opt1 = highlighter(param.opts[0])
-                    opt2 = highlighter(param.opts[1])
-                    # Secondary opts (eg. --debug/--no-debug)
-                    if param.secondary_opts:
-                        opt1 += highlighter("/" + param.secondary_opts[0])
-                        opt2 += highlighter("/" + param.secondary_opts[1])
+            opt_long_strs = []
+            opt_short_strs = []
+            for idx, opt in enumerate(param.opts):
+                opt_str = opt
+                if param.secondary_opts and idx in param.secondary_opts:
+                    opt_str += "/" + param.secondary_opts[idx]
+                if "--" in opt:
+                    opt_long_strs.append(opt_str)
                 else:
-                    opt1 = highlighter(param.opts[1])
-                    opt2 = highlighter(param.opts[0])
-                    # Secondary opts (eg. --debug/--no-debug)
-                    if param.secondary_opts:
-                        opt1 += highlighter("/" + param.secondary_opts[1])
-                        opt2 += highlighter("/" + param.secondary_opts[1])
-            # Just one form
-            else:
-                opt1 = highlighter(param.opts[0])
-                opt2 = Text("")
-                if param.secondary_opts:
-                    opt1 += highlighter("/" + param.secondary_opts[0])
+                    opt_short_strs.append(opt_str)
 
             # Column for a metavar, if we have one
             metavar = Text(style=STYLE_METAVAR)
@@ -407,8 +396,8 @@ def rich_format_help(obj, ctx, formatter):
 
             rows = [
                 required,
-                highlighter(opt1),
-                highlighter(opt2),
+                highlighter(highlighter(",".join(opt_long_strs))),
+                highlighter(highlighter(",".join(opt_short_strs))),
                 metavar,
                 _get_parameter_help(param, ctx),
             ]
@@ -462,7 +451,12 @@ def rich_format_help(obj, ctx, formatter):
                 if command not in obj.list_commands(ctx):
                     continue
                 cmd = obj.get_command(ctx, command)
-                helptext = cmd.help or ""
+                # Use the truncated short text as with vanilla text if requested
+                if USE_CLICK_SHORT_HELP:
+                    helptext = cmd.get_short_help_str()
+                else:
+                    # Use short_help function argument if used, or the full help
+                    helptext = cmd.short_help or cmd.help or ""
                 commands_table.add_row(command, _make_command_help(helptext))
             if commands_table.row_count > 0:
                 console.print(
@@ -512,13 +506,13 @@ def rich_format_error(self):
         highlighter=highlighter,
         color_system=COLOR_SYSTEM,
     )
-    if self.ctx is not None:
+    if getattr(self, "ctx", None) is not None:
         console.print(self.ctx.get_usage())
     if ERRORS_SUGGESTION:
         console.print(ERRORS_SUGGESTION, style=STYLE_ERRORS_SUGGESTION)
     elif (
         ERRORS_SUGGESTION is None
-        and self.ctx is not None
+        and getattr(self, "ctx", None) is not None
         and self.ctx.command.get_help_option(self.ctx) is not None
     ):
         console.print(
